==> AnnBuilder_1.3.3.tar.gz: AnnBuilder/R/KEGGPkgBuilder.R <==
# This function creates a data package containing mappings between
# KEGG pathway names and pathway ids and enzyme ids and GO ids.
#
# Copyright 2002, J. Zhang. All rights reserved.
#

KEGGPkgBuilder <- function(pkgPath, pkgName = "KEGG", version = "1.0.1",
                         pathwayURL = getKEGGFile("path"),
                         enzymeURL = getKEGGFile("enzyme"),
                         force = TRUE, author = list(author = "who",
                         maintainer = "who@email.com")){
    # Create two environments to hold the parsed data
    pNameEnv <- new.env(hash = TRUE, parent = NULL)
    pIdEnv <- new.env(hash = TRUE, parent = NULL)
    makeSrcInfo()
    createEmptyDPkg(pkgName, pkgPath)
    # Write mappings between path ids and path names
    idNName <- getKEGGIDNName(pathwayURL, "")
    multiassign(idNName, names(idNName), env = pNameEnv)
    multiassign(names(idNName), idNName, env = pIdEnv)
    assign(paste(pkgName, "PATHNAME2ID", sep = ""), pNameEnv)
    assign(paste(pkgName, "PATHID2NAME", sep = ""), pIdEnv)
    save(list = paste(pkgName, "PATHNAME2ID", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "PATHNAME2ID.rda", sep = "")))
    save(list = paste(pkgName, "PATHID2NAME", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "PATHID2NAME.rda", sep = "")))
    # Writes mappings between GO and enzyme
    enzymeIdNGO <- getEIdNName(enzymeURL)
    enzymeGOEnv <- new.env(hash = TRUE, parent = NULL)
    goEnzymeEnv <- new.env(hash = TRUE, parent = NULL)
    multiassign(enzymeIdNGO[,1], enzymeIdNGO[,2], env = enzymeGOEnv)
    multiassign(enzymeIdNGO[,2], enzymeIdNGO[,1], env = goEnzymeEnv)
    assign(paste(pkgName, "ENZYMEID2GO", sep = ""), enzymeGOEnv)
    assign(paste(pkgName, "GO2ENZYMEID", sep = ""), goEnzymeEnv)
    save(list = paste(pkgName, "ENZYMEID2GO", sep = ""),
         file =   file.path(pkgPath, pkgName, "data",
         paste(pkgName, "ENZYMEID2GO.rda", sep = "")))
    save(list = paste(pkgName, "GO2ENZYMEID", sep = ""),
         file =   file.path(pkgPath, pkgName, "data",
         paste(pkgName, "GO2ENZYMEID.rda", sep = "")))
    # Write man pages and other files
    writeAccessory(pkgName, pkgPath, organism = "KEGG",
                   version = version, author = author)
    writeDescription(pkgName, pkgPath, version, author)
    # Write Rd files for all the rda files that already exist in data
    for(i in getAllRdaName(pkgName, pkgPath)){
        writeManPage(pkgName, pkgPath, i,
                     src = get(i, AnnInfo)$src)
    }
    # Write a function that displays data information when called
    # using pkgName() and the man page for the function
    writeFun (pkgPath, pkgName)
    writeMan4Fun(pkgName, pkgPath)
    # Write .First.lib
    writeZZZ(pkgPath, pkgName)
    # Quality control
    getDPStats("", pkgName, pkgPath)
    writeMan4QC(pkgName, pkgPath)
}

getEIdNName <- function(enzymeURL =
                        "http://www.geneontology.org/external2go/ec2go"){

    kegg <- KEGG(srcUrl = enzymeURL)
    fileGot <- readData(kegg)

    getECNGO <- function(vect){
        return(c(vect[1], vect[length(vect)]))
    }
    # Remove the header if any
    if(length(grep("^!", fileGot)) > 0){
        fileGot <- fileGot[-grep("^!", fileGot)]
    }
    # Split entries using a space
    fileGot <- sapply(sapply(fileGot, strsplit, " "), unlist)
    # Create a matrix using the splited data
    fileGot <- matrix(sapply(fileGot, getECNGO), ncol = 2, byrow = TRUE)

    return(fileGot)
}


getKEGGFile <- function(whichOne){
    switch(tolower(whichOne),
           "path" = return(paste(getSrcUrl("KEGG"), "/",
                    "map_title.tab", sep = "")),
           "enzyme" = return("http://www.geneontology.org/external2go/ec2go"),
           stop("Name has to be eith path or enzyme!"))
}

==> AnnBuilder_1.4.2.tar.gz: AnnBuilder/R/KEGGPkgBuilder.R <==
# This function creates a data package containing mappings between
# KEGG pathway names and pathway ids and enzyme ids and GO ids.
#
# Copyright 2002, J. Zhang. All rights reserved.
#

KEGGPkgBuilder <- function(pkgPath, pkgName = "KEGG", version = "1.0.1",
                         pathwayURL = getKEGGFile("path"),
                         enzymeURL = getKEGGFile("enzyme"),
                         geneMapURL = getKEGGFile("geneMap"),
                         force = TRUE, author = list(author = "who",
                         maintainer = "who@email.com")){
    # Create two environments to hold the parsed data
    pNameEnv <- new.env(hash = TRUE, parent = NULL)
    pIdEnv <- new.env(hash = TRUE, parent = NULL)
    makeSrcInfo()
    createEmptyDPkg(pkgName, pkgPath)
    # Write mappings between path ids and path names
    idNName <- getKEGGIDNName(pathwayURL, "")
    multiassign(idNName, names(idNName), env = pNameEnv)
    multiassign(names(idNName), idNName, env = pIdEnv)
    assign(paste(pkgName, "PATHNAME2ID", sep = ""), pNameEnv)
    assign(paste(pkgName, "PATHID2NAME", sep = ""), pIdEnv)
    save(list = paste(pkgName, "PATHNAME2ID", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "PATHNAME2ID.rda", sep = "")))
    save(list = paste(pkgName, "PATHID2NAME", sep = ""),
         file =  file.path(pkgPath, pkgName, "data",
         paste(pkgName, "PATHID2NAME.rda", sep = "")))
    # Writes mappings between GO and enzyme
    enzymeIdNGO <- getEIdNName(enzymeURL)
    enzymeGOEnv <- new.env(hash = TRUE, parent = NULL)
    goEnzymeEnv <- new.env(hash = TRUE, parent = NULL)
    multiassign(enzymeIdNGO[,1], enzymeIdNGO[,2], env = enzymeGOEnv)
    multiassign(enzymeIdNGO[,2], enzymeIdNGO[,1], env = goEnzymeEnv)
    assign(paste(pkgName, "ENZYMEID2GO", sep = ""), enzymeGOEnv)
    assign(paste(pkgName, "GO2ENZYMEID", sep = ""), goEnzymeEnv)
    save(list = paste(pkgName, "ENZYMEID2GO", sep = ""),
         file =   file.path(pkgPath, pkgName, "data",
         paste(pkgName, "ENZYMEID2GO.rda", sep = "")))
    save(list = paste(pkgName, "GO2ENZYMEID", sep = ""),
         file =   file.path(pkgPath, pkgName, "data",
         paste(pkgName, "GO2ENZYMEID.rda", sep = "")))
    keggGeneMap <- getKEGGGeneMap()
    saveMat(keggGeneMap, pkgName, pkgPath, "EXTID2PATHID", keyCol = 1,
                         valCol = 2, fun = splitEntry)
    saveMat(getReverseMapping(keggGeneMap, sep = ";"), pkgName,
                         pkgPath, "PATHID2EXTID", keyCol = 1,
            valCol = 2, fun = splitEntry)
    # Write man pages and other files
    writeAccessory(pkgName, pkgPath, organism = "KEGG",
                   version = version, author = author)
    writeDescription(pkgName, pkgPath, version, author,
                     "KEGG", paste("Free for academic use.",
                                   "Non-academic users are requested",
                                   "to\n   obtain a license agreement",
                                   "with KEGG"))
    # Write Rd files for all the rda files that already exist in data
    for(i in getAllRdaName(pkgName, pkgPath)){
        writeManPage(pkgName, pkgPath, i,
                     src = get(i, AnnInfo)$src)
    }
    # Write a function that displays data information when called
    # using pkgName() and the man page for the function
    writeFun (pkgPath, pkgName)
    writeMan4Fun(pkgName, pkgPath)
    # Write .First.lib
    writeZZZ(pkgPath, pkgName)
    # Quality control
    getDPStats("", pkgName, pkgPath)
    writeMan4QC(pkgName, pkgPath)
}

getEIdNName <- function(enzymeURL =
                        "http://www.geneontology.org/external2go/ec2go"){

    kegg <- KEGG(srcUrl = enzymeURL)
    fileGot <- readData(kegg)

    getECNGO <- function(vect){
        return(c(vect[1], vect[length(vect)]))
    }
    # Remove the header if any
    if(length(grep("^!", fileGot)) > 0){
        fileGot <- fileGot[-grep("^!", fileGot)]
    }
    # Split entries using a space
    fileGot <- sapply(sapply(fileGot, strsplit, " "), unlist)
    # Create a matrix using the splited data
    fileGot <- matrix(sapply(fileGot, getECNGO), ncol = 2, byrow = TRUE)

    return(fileGot)
}


getKEGGFile <- function(whichOne, organism = "human"){
    switch(tolower(whichOne),
           path = return(paste(getSrcUrl("KEGG"), "/",
                    "map_title.tab", sep = "")),
           enzyme = return("http://www.geneontology.org/external2go/ec2go"),
           genemap = return(paste(getSrcUrl("KEGG"),
                       getKEGGOrgName(organism),
                       paste(getKEGGOrgName(organism), "_gene_map.tab",
                             sep = ""), sep = "/")),
           stop("Invalid option for file name"))
}
